summaryrefslogtreecommitdiff
path: root/src/check.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/check.h')
-rw-r--r--src/check.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/check.h b/src/check.h
index ae05988..0a076ba 100644
--- a/src/check.h
+++ b/src/check.h
@@ -1,4 +1,4 @@
/* check.h - Check and repair a PC/MS-DOS file system
Copyright (C) 1993 Werner Almesberger <werner.almesberger@lrc.di.epfl.ch>
Copyright (C) 2008-2013 Daniel Baumann <mail@daniel-baumann.ch>
@@ -16,7 +16,7 @@
You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
- On Debian systems, the complete text of the GNU General Public License
+ The complete text of the GNU General Public License
can be found in /usr/share/common-licenses/GPL-3 file.
*/
@@ -34,7 +34,7 @@ loff_t alloc_rootdir_entry(DOS_FS * fs, DIR_ENT * de, const char *pattern);
int scan_root(DOS_FS * fs);
/* Scans the root directory and recurses into all subdirectories. See check.c
- for all the details. Returns a non-zero integer if the file system has to
+ for all the details. Returns a non-zero integer if the filesystem has to
be checked again. */
#endif
@@ -1,4 +1,4 @@
-/* check.h - Check and repair a PC/MS-DOS file system
+/* check.h - Check and repair a PC/MS-DOS filesystem
Copyright (C) 1993 Werner Almesberger <werner.almesberger@lrc.di.epfl.ch>
Copyright (C) 2008-2013 Daniel Baumann <mail@daniel-baumann.ch>